@@ -6,10 +6,10 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.007_001'; # TRIAL VERSION
+our $VERSION = '0.001'; # VERSION
 
 use Moo;
-extends 'Chart::Kaleido';
+extends 'Chart::Kaleido::Base';
 
 use File::ShareDir;
 use JSON;
@@ -25,82 +25,60 @@ use namespace::autoclean;
 my @text_formats = qw(svg json eps);
 
 
-my $default_plotlyjs = sub {
-    my $plotlyjs;
-    eval {
-        $plotlyjs = File::ShareDir::dist_file( 'Chart-Plotly',
-            'plotly.js/plotly.min.js' );
-    };  
-    return $plotlyjs;
-};
+has '+all_formats' =>
+  ( default => sub { [qw(png jpg jpeg webp svg pdf eps json)] } );
+
+has '+scope_name' => ( default => 'plotly' );
+
+has '+scope_flags' =>
+  ( default => sub { [qw(plotlyjs mathjax topojson mapbox_access_token)] }, );
+
+has '+base_args' =>
+  ( default => sub { [ qw(plotly --disable-gpu) ] } );
+
 
 has plotlyjs => (
     is      => 'ro',
-    isa     => ( Str->plus_coercions( Undef, $default_plotlyjs ) | Undef ),
-    default => $default_plotlyjs,
+    isa     => (Str | Undef),
     coerce  => 1,
+    builder => sub {
+        my $plotlyjs;
+        eval {
+            $plotlyjs = File::ShareDir::dist_file( 'Chart-Plotly',
+                'plotly.js/plotly.min.js' );
+        };
+        return $plotlyjs;
+    },
 );
 
 has [qw(mathjax topojson)] => (
     is     => 'ro',
-    isa    => ( Str | Undef ),
+    isa    => (Str | Undef),
     coerce => 1,
 );
 
 has mapbox_access_token => (
     is  => 'ro',
-    isa => ( Str | Undef ),
+    isa => (Str | Undef),
 );
 
 
-my $PositiveInt = Int->where( sub { $_ > 0 } );
-
-has default_format => (
-    is      => 'ro',
-    isa     => Str,
-    default => 'png',
-);
-
-has default_width => (
-    is      => 'ro',
-    isa     => $PositiveInt,
-    default => 700,
-);
-
-has default_height => (
-    is      => 'ro',
-    isa     => $PositiveInt,
-    default => 500,
-);
-
-has '+base_args' => (
-    default => sub {
-        my $self = shift;
-        [ "plotly", @{ $self->_default_chromium_args }, "--no-sandbox" ];
-    }
-);
-
-sub all_formats { [qw(png jpg jpeg webp svg pdf eps json)] }
-sub scope_name  { 'plotly' }
-sub scope_flags { [qw(plotlyjs mathjax topojson mapbox_access_token)] }
-
-
 sub transform {
     my $self = shift;
     state $check = compile_named_oo(
     #<<< no perltidy
-        plot   => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
-        format => Optional[Str], { default => sub { $self->default_format } },
-        width  => $PositiveInt, { default => sub { $self->default_width } },
-        height => $PositiveInt, { default => sub { $self->default_height} },
+        plotly => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
+        format => Optional[Str],
+        width  => Int,
+        height => Int,
         scale  => Num, { default => 1 },
     #>>>
     );
     my $arg = $check->(@_);
-    my $plot =
-        $arg->plot->$_isa('Chart::Plotly::Plot')
-      ? $arg->plot->TO_JSON
-      : $arg->plot;
+    my $plotly =
+        $arg->plotly->$_isa('Chart::Plotly::Plot')
+      ? $arg->plotly->TO_JSON
+      : $arg->plotly;
     my $format = lc( $arg->format );
 
     unless ( grep { $_ eq $format } @{ $self->all_formats } ) {
@@ -113,10 +91,8 @@ sub transform {
         width  => $arg->width,
         height => $arg->height,
         scale  => $arg->scale,
-        data   => $plot,
+        data   => $plotly,
     };
-
-    local *PDL::TO_JSON = sub { $_[0]->unpdl };
     my $resp = $self->do_transform($data);
     if ( $resp->{code} != 0 ) {
         die $resp->{message};
@@ -132,11 +108,11 @@ sub save {
     my $self = shift;
     state $check = compile_named_oo(
     #<<< no perltidy
-        file   => Path,
-        plot   => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
+        file    => Path,
+        plotly => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
         format => Optional[Str],
-        width  => $PositiveInt, { default => sub { $self->default_width } },
-        height => $PositiveInt, { default => sub { $self->default_height} },
+        width  => Int,
+        height => Int,
         scale  => Num, { default => 1 },
     #>>>
     );
@@ -151,7 +127,7 @@ sub save {
     $format = lc($format);
 
     my $img = $self->transform(
-        plot   => $arg->plot,
+        plotly => $arg->plotly,
         format => $format,
         width  => $arg->width,
         height => $arg->height,
@@ -174,30 +150,19 @@ Chart::Kaleido::Plotly - Export static images of Plotly charts using Kaleido
 
 =head1 VERSION
 
-version 0.007_001
+version 0.001
 
 =head1 SYNOPSIS
 
     use Chart::Kaleido::Plotly;
     use JSON;
 
-    my $kaleido = Chart::Kaleido::Plotly->new();
-
-    # convert a hashref
     my $data = decode_json(<<'END_OF_TEXT');
     { "data": [{"y": [1,2,1]}] }
     END_OF_TEXT
-    $kaleido->save( file => "foo.png", plot => $data,
-                    width => 1024, height => 768 );
 
-    # convert a Chart::Plotly::Plot object
-    use Chart::Plotly::Plot;
-    my $plot = Chart::Plotly::Plot->new(
-        traces => [
-            Chart::Plotly::Trace::Scatter->new( x => [ 1 .. 5 ], y => [ 1 .. 5 ] )
-        ]
-    );
-    $kaleido->save( file => "foo.png", plot => $plot,
+    my $kaleido = Chart::Kaleido::Plotly->new();
+    $kaleido->save( file => "foo.png", plotly => decode_json($data),
                     width => 1024, height => 768 );
 
 =head1 DESCRIPTION
@@ -208,6 +173,10 @@ This class wraps the "plotly" scope of plotly's kaleido command.
 
 =head2 timeout
 
+=head2 all_formats
+
+All supported formats.
+
 =head2 plotlyjs
 
 Path to plotly js file.
@@ -219,38 +188,22 @@ Default value is plotly js bundled with L<Chart::Ploly>.
 
 =head2 mapbox_access_token
 
-=head2 default_format
-
-Default is "png".
-
-=head2 default_width
-
-Default is 700.
-
-=head2 default_height
-
-Default is 500.
-
 =head1 METHODS
 
 =head2 transform
 
-    transform(( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plot,
-              Str :$format=$self->default_format,
-              PositiveInt :$width=$self->default_width,
-              PositiveInt :$height=$self->default_height,
-              Num :$scale=1)
+    transform(( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plotly,
+              Optional[Str] :$format,
+              Int :$width, Int :$height, Num :$scale=1)
 
 Returns raw image data.
 
 =head2 save
 
     save(:$file,
-         ( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plot,
+         ( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plotly,
          Optional[Str] :$format,
-         PositiveInt :$width=$self->default_width,
-         PositiveInt :$height=$self->default_height,
-         Num :$scale=1)
+         Int :$width, Int :$height, Num :$scale=1)
 
 Save static image to file.
 
@@ -259,7 +212,7 @@ Save static image to file.
 L<https://github.com/plotly/Kaleido>
 
 L<Chart::Plotly>,
-L<Chart::Kaleido>,
+L<Chart::Kaleido::Base>,
 L<Alien::Plotly::Kaleido>
 
 =head1 AUTHOR
@@ -268,7 +221,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020-2021 by Stephan Loyd.
+This software is copyright (c) 2020 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
